DTBadge class

Inheritance

Constructors

DTBadge({Key? key, TextStyle? textStyle, ShapeBorder? borderShape, DTBadgeShape shape = DTBadgeShape.standard, Color color = DTColors.DANGER, Color textColor = DTColors.WHITE, double size = DTSize.SMALL, BorderSide? border, String? text, Widget? child})
Create badges of all types, check out DTButtonBadge for button badges and DTIconBadge for icon type badges
const

Properties

border BorderSide?
The border side for the badge's Material.
final
borderShape ShapeBorder?
Typically the counter badge's shape.
final
child Widget?
child of type Widget is alternative to child. text will get priority over child
final
color Color
Pass DTColors or Color
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape DTBadgeShape
Counter type of DTBadgeShape i.e, standard, pills, square, circle
final
size double
size of double or DTSize i.e, 1.2, small, medium, large etc.
final
text String?
text of type String is alternative to child. text will get priority over child
final
textColor Color
Pass DTColors or Color
final
textStyle TextStyle?
text style of counter text.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _DTBadgeState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited