badgeBoxShadow property
on true state default box shadow appears around badge, if DTButtonType is solid
Implementation
final bool? badgeBoxShadow;
on true state default box shadow appears around badge, if DTButtonType is solid
final bool? badgeBoxShadow;