buttonBoxShadow property
on true state default box shadow appears around button, if DTButtonType is solid
Implementation
final bool? buttonBoxShadow;
on true state default box shadow appears around button, if DTButtonType is solid
final bool? buttonBoxShadow;