DTSize class
Constructors
- DTSize()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- LARGE → const double
- DTSize.LARGE is used for large size widget
- MEDIUM → const double
- Default size if DTSize.MEDIUM is used for medium size widget
- SMALL → const double
- DTSize.SMALL is used for small size widget